package com.shigongli.common;

import com.aliyun.oss.OSSClient;
import com.shigongli.config.AliyunConfig;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;

import java.io.*;

@Component
public class OSSUtils {

    @Autowired
    AliyunConfig aliyunConfig;

    /**
     * 上传文件
     * @param mf 上传的文件
     * @param toDirs 上传到的目录
     * @return
     */
    public String putObject(MultipartFile mf, String ... toDirs) throws IOException {
        String fName = formatFileName(mf.getOriginalFilename());
        String preFix = String.valueOf(System.currentTimeMillis());
        String toDir = "/";
        if (null != toDirs && toDirs.length > 0) {
            toDir = toDirs[0];
        }
        String nwFName = toDir + preFix + "-" + fName;
        nwFName = StringUtils.trim(nwFName,"/");

        return putFile(nwFName, new ByteArrayInputStream(mf.getBytes()));
    }

    public String putObject(File f, String ... toDirs) throws FileNotFoundException {
        String fName = formatFileName(f.getName());
        String preFix = String.valueOf(System.currentTimeMillis());
        String toDir = "/";
        if (null != toDirs && toDirs.length > 0) {
            toDir = toDirs[0];
        }
        String nwFName = toDir + preFix + "-" + fName;
        nwFName = StringUtils.trim(nwFName,"/");

        InputStream inputStream = new FileInputStream(f);
        return putFile(nwFName, inputStream);
    }

    private String formatFileName(String fName) {
        return StringUtils.ifNull(fName, StringUtils.random(16) + ".png");
    }

    private String putFile(String fname, InputStream input) {
        OSSClient ossClient = new OSSClient(aliyunConfig.getOss().getEndpoint(), aliyunConfig.getAccessKeyId(), aliyunConfig.getAccessKeySecret());
        ossClient.putObject(aliyunConfig.getOss().getBucketName(), fname, input);
        ossClient.shutdown();

        // String url = ossClient.generatePresignedUrl(AliOSSUtils.oss.getBucketName(), fname, expiration).toString();

        String preURL = aliyunConfig.getOss().getBucketURL();
        if (!preURL.endsWith("/")) {
            preURL += "/";
        }

        return preURL + fname.replaceAll("\\ ", "%20");
    }
}
