package com.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.shigongli.common.BaseController;
import com.shigongli.common.ResponseBean;
import com.shigongli.constants.StatusConstant;
import com.shigongli.entity.TaMateTag;
import com.shigongli.service.ITaMateTagService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.shigongli.service.ITaMateTagGroupService;
import com.shigongli.entity.TaMateTagGroup;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * <p>
    * 素材标签组 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-12-11
 */

@Api(tags = "素材标签组")
@RestController
@RequestMapping("/")
public class TaMateTagGroupController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaMateTagGroupController.class);

    @Autowired
    public ITaMateTagGroupService iTaMateTagGroupService;

    @Autowired
    public ITaMateTagService iTaMateTagService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/mp/taMateTagGroup",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taMateTagGroupList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

        IPage<TaMateTagGroup> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaMateTagGroup> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("status", StatusConstant.NORMAL);
        queryWrapper.orderByDesc("create_date");

        IPage<TaMateTagGroup> result = iTaMateTagGroupService.page(pg, queryWrapper);

        // 获取组下所有标签
        if (null != result.getRecords()) {
            for (TaMateTagGroup item: result.getRecords()) {
                List<TaMateTag> taMateTagList = iTaMateTagService.getByGroup(item.getGroupId());
                item.setTaMateTagList(taMateTagList);
            }
        }

        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taMateTagGroup 实体对象
     * @return
     */
    @RequestMapping(value="/mp/taMateTagGroup",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taMateTagGroupAdd(@ApiParam("保存内容") @RequestBody TaMateTagGroup taMateTagGroup) throws Exception{

        if (iTaMateTagGroupService.save(taMateTagGroup)){
            return ResponseBean.success(taMateTagGroup);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/mp/taMateTagGroup/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taMateTagGroupDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TaMateTagGroup taMateTagGroup = iTaMateTagGroupService.getById(id);
        if (null == taMateTagGroup || taMateTagGroup.getStatus().equals(StatusConstant.DELETE)) {
            return ResponseBean.success("ok");
        }

        taMateTagGroup.setStatus(StatusConstant.DELETE);
        return taMateTagGroupUpdate(id, taMateTagGroup);
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taMateTagGroup 实体对象
     * @return
     */
    @RequestMapping(value="/mp/taMateTagGroup/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taMateTagGroupUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaMateTagGroup taMateTagGroup) throws Exception{

        if (iTaMateTagGroupService.updateById(taMateTagGroup)){
            return ResponseBean.success(iTaMateTagGroupService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/mp/taMateTagGroup/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taMateTagGroupGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaMateTagGroupService.getById(id));
    }
}
